@@ -21,11 +21,13 @@ def _get_args(call_args):
 
     parser.add_argument('--types', dest='types', type=str, nargs='*',
                         default=['py'],
-                        help='Process given file types. Default value is "py"')
+                        help='Process given file types. Default value is "py".')
     parser.add_argument('paths', type=str, nargs='+')
     parser.add_argument('-r', '--recursive', dest='recursive',
                         action='store_true', default=False,
                         help='Process files found in subdirectories.')
+    parser.add_argument('--no-semicolon', action='store_true', default=False,
+                        help='Try to detect SQL queries with no trailing semicolon.')
 
     args, _unused_unknown_args = parser.parse_known_args(call_args)
     return args
@@ -37,7 +39,7 @@ def main(call_args=sys.argv):
     for file_type, path in product(args.types, args.paths):
         for filename in _get_file_in_path(path, file_type, args.recursive):
             print(filename)
-            format_file(filename, file_type)
+            format_file(filename, file_type, not args.no_semicolon)
 
 
 if __name__ == '__main__':
